@@ -54,8 +54,6 @@ pub mod finish_file_data_upload_request;
 pub use self::finish_file_data_upload_request::FinishFileDataUploadRequest;
 pub mod friend_status;
 pub use self::friend_status::FriendStatus;
-pub mod inline_response_404;
-pub use self::inline_response_404::InlineResponse404;
 pub mod instance;
 pub use self::instance::Instance;
 pub mod instance_platforms;
@@ -68,6 +66,14 @@ pub mod invite_request;
 pub use self::invite_request::InviteRequest;
 pub mod invite_response;
 pub use self::invite_response::InviteResponse;
+pub mod license;
+pub use self::license::License;
+pub mod license_action;
+pub use self::license_action::LicenseAction;
+pub mod license_group;
+pub use self::license_group::LicenseGroup;
+pub mod license_type;
+pub use self::license_type::LicenseType;
 pub mod limited_unity_package;
 pub use self::limited_unity_package::LimitedUnityPackage;
 pub mod limited_user;
@@ -96,8 +102,22 @@ pub mod release_status;
 pub use self::release_status::ReleaseStatus;
 pub mod response;
 pub use self::response::Response;
+pub mod subscription;
+pub use self::subscription::Subscription;
+pub mod subscription_period;
+pub use self::subscription_period::SubscriptionPeriod;
 pub mod success;
 pub use self::success::Success;
+pub mod transaction;
+pub use self::transaction::Transaction;
+pub mod transaction_agreement;
+pub use self::transaction_agreement::TransactionAgreement;
+pub mod transaction_status;
+pub use self::transaction_status::TransactionStatus;
+pub mod transaction_steam_info;
+pub use self::transaction_steam_info::TransactionSteamInfo;
+pub mod transaction_steam_wallet_info;
+pub use self::transaction_steam_wallet_info::TransactionSteamWalletInfo;
 pub mod two_factor_auth_code;
 pub use self::two_factor_auth_code::TwoFactorAuthCode;
 pub mod unity_package;
@@ -120,6 +140,8 @@ pub mod user_state;
 pub use self::user_state::UserState;
 pub mod user_status;
 pub use self::user_status::UserStatus;
+pub mod user_subscription;
+pub use self::user_subscription::UserSubscription;
 pub mod verify2_fa_result;
 pub use self::verify2_fa_result::Verify2FaResult;
 pub mod verify_auth_token_result;
